<template>
  <j-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    @ok="handleOk"
    @cancel="close"
    :mask-closable="false"
    cancelText="关闭">
    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :model="model" :rules="validatorRules" :labelCol="labelCol" :wrapperCol="wrapperCol">
        <a-row>
          <a-col :span="12">
            <a-form-model-item prop="equipmentId" label="设备编号">
              <lx-search-equipment-select placeholder="请输入设备编号或名称搜索" v-model="model.equipmentId"/>
            </a-form-model-item>
          </a-col>

          <a-col :span="12">
            <a-form-model-item prop="faultName" label="故障简称">
              <a-select placeholder="请选择故障简称" v-model="model.faultName" @change="handleFaultNameChange">
                <a-select-option v-for="item in faultReasonList" :key="item.faultName">
                  {{ item.faultName }}
                </a-select-option>
              </a-select>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row>
          <a-col :span="12">
            <a-form-model-item label="故障分类">
              <a-input placeholder="请输入故障分类" v-model="model.faultType_dictText" readOnly/>
            </a-form-model-item>
          </a-col>

          <a-col :span="12">
            <a-form-model-item label="故障描述">
              <a-input placeholder="请输入故障描述" v-model="model.faultDescription" readOnly/>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row>
          <a-col :span="12">
            <a-form-model-item prop="faultStartTime" label="故障开始时间">
              <a-date-picker showTime placeholder="请选择故障开始时间" v-model="model.faultStartTime"
                             :allow-clear="false" value-format="YYYY-MM-DD HH:mm:ss"/>
            </a-form-model-item>
          </a-col>

          <a-col :span="12">
            <a-form-model-item prop="breakdownFlag" label="是否停机">
              <a-radio-group v-model="model.breakdownFlag">
                <a-radio v-for="item in breakdownFlagList" :value="item.value">{{ item.label }}</a-radio>
              </a-radio-group>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row>
          <a-col :span="24">
            <a-form-model-item prop="imageFiles" label="报修图片" :labelCol="labelColLong" :wrapperCol="wrapperColLong">
              <j-image-upload v-model="model.imageFiles" :is-multiple="true" :number="3"/>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row>
          <a-col :span="24">
            <a-form-model-item prop="remark" label="备注" :labelCol="labelColLong" :wrapperCol="wrapperColLong">
              <a-textarea placeholder="请输入备注" v-model="model.remark"/>
            </a-form-model-item>
          </a-col>
        </a-row>
        <!--        <a-form-model-item  prop="reportStatus" label="报修状态">-->
        <!--          <a-input placeholder="请输入报修状态" v-model="model.reportStatus" />-->
        <!--        </a-form-model-item>-->

      </a-form-model>
    </a-spin>
  </j-modal>
</template>

<script>
import { httpAction } from '@/api/manage'
import LxSearchEquipmentSelect from '@views/eam/equipment/modules/LxSearchEquipmentSelect.vue'

export default {
  name: 'EamReportRepairModal',
  components: { LxSearchEquipmentSelect },
  props: {
    breakdownFlagList: {
      type: Array
    },
    faultReasonList: {
      type: Array
    }
  },
  data() {
    return {
      title: '操作',
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 12 }
      },
      labelColLong: {
        xs: { span: 24 },
        sm: { span: 4 }
      },
      wrapperColLong: {
        xs: { span: 24 },
        sm: { span: 18 }
      },
      confirmLoading: false,
      validatorRules: {
        faultStartTime: [
          { required: true, message: '请选择故障开始时间' }
        ],
        breakdownFlag: [
          { required: true, message: '请选择是否停机' }
        ],
        equipmentId: [
          { required: true, message: '请输入设备编号或名称搜索' }
        ],
        faultName: [
          { required: true, message: '请选择故障简称' }
        ]
      },
      url: {
        add: '/eam/eamReportRepair/add',
        edit: '/eam/eamReportRepair/edit'
      }
    }
  },
  created() {
  },
  methods: {
    add() {
      //初始化默认值
      this.edit({
        breakdownFlag: this.breakdownFlagList.find(item => item.label === '是').value
      })
    },
    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
    },
    handleFaultNameChange(value) {
      const faultReasonItem = this.faultReasonList.find(item => item.faultName === value)
      this.model.faultType = faultReasonItem.faultCategory
      this.model.faultType_dictText = faultReasonItem.faultCategory_dictText
      this.model.faultDescription = faultReasonItem.faultDescription
    },

    handleOk() {
      const that = this
      // 触发表单验证
      console.log('model---------------', that.model)
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true
          let httpUrl = ''
          let method = ''
          if (!this.model.id) {
            httpUrl += this.url.add
            method = 'post'
          } else {
            httpUrl += this.url.edit
            method = 'put'
          }
          httpAction(httpUrl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
          })
        } else {
          return false
        }
      })
    },

    close() {
      this.$emit('close')
      this.visible = false
      this.$refs.form.clearValidate()
    }
  }
}
</script>

<style lang="less" scoped>

</style>